import sys
import os
import argparse
import math
from PIL import Image

def sliceit(args):

    startup = [args.source]
    images = []
    while startup:
        if os.path.isdir(startup[0]):
            for item in os.scandir(startup[0]):
                startup.append(item.path)
        else:
            images.append(startup[0])
        startup.pop(0)

    with Image.open(args.source) as img:
        if args.rows and args.columns:
            args.width = img.width / args.columns
            args.height = img.height / args.rows
        height = img.height
        width = img.width
    rows = math.ceil(height / args.height)
    cols = math.ceil(width / args.width)
    total = rows * cols

    zf = len(str(total))
    x = 0
    y = 0
    xx = args.width
    yy = args.height
    z = 0
    img = Image.open(args.source)
    while True:
        base, ext = os.path.splitext(args.source)
        output = f"{base}-{str(z).zfill(zf)}{ext}"
        if xx > width:
            x = 0
            xx = args.width
            y += args.height
            yy += args.height
        if yy > height:
            print(f"Sliced out a total of {total} images!")
            sys.exit()
        box = (x,y,xx,yy)
        img.crop(box).save(output)
        x += args.width
        xx += args.width
        z += 1

def main(argv=None):
    argv = (argv or sys.argv)[1:]
    parser = argparse.ArgumentParser()
    parser.add_argument('source', type=str, help="source image to slice")
    parser.add_argument('-x', '--width', dest='width', type=int)
    parser.add_argument('-y', '--height', dest='height', type=int)
    parser.add_argument('-r', '--rows', dest='rows', type=int)
    parser.add_argument('-c', '--columns', dest='columns', type=int)

    parser.set_defaults(func=sliceit)
    args, options = parser.parse_known_args(argv)
    if not args.width and not args.height and options and not args.rows and not args.columns:

        args.width = int(options[0])
        args.height = int(options[1])
    if not isinstance(args.height, int) and not isinstance(args.width, int) and not args.rows and not args.columns:
        parser.error('error')

    args.func(args)

if __name__ == '__main__':
    sys.exit(main())



import os
import sys
import shutil
import platform
import argparse
import subprocess
import regex as re


def details():

    sys.stdout.write(f"\x1b[4m{platform.platform()}\x1b[0m\n\n")


def frequency():
    path = f"/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq"
    if os.path.exists(path):
        sys.stdout.write(f"\x1b[4mCPU Freqs (0-{os.cpu_count()-1})\x1b[0m\n")
    for i in range(os.cpu_count()):
        path = f"/sys/devices/system/cpu/cpu{i}/cpufreq/scaling_cur_freq"
        if os.path.exists(path):
            with open(path) as f:
                data = int(f.read()) / 1000000
            sys.stdout.write(f"  CPU {i}: {data:.2f} GHz\n")


def temperature():
    path = "/sys/class/thermal/thermal_zone0/temp"
    if os.path.exists(path):
        with open(path) as f:
            data = int(f.read()) / 1000
        sys.stdout.write(f"\x1b[4mTemperature\x1b[0m\n  {data:.1f}\u00b0C | {data * 9 / 5 + 32:.1f}\u00b0F\n")

    # Specific to my device only.
    else:
        process = subprocess.run('sensors nvme-pci-0100 amdgpu-pci-0400', capture_output=True, shell=True)
        return_code = process.returncode

        if process.returncode != 0:
            return

        output = process.stdout.decode()
        
        cpu_pattern = re.compile(r'(?<=Composite: +\+)\d+\.\d+')
        gpu_pattern = re.compile(r'(?<=edge: +\+)\d+\.\d+')


        ctc = float(cpu_pattern.search(output).group())
        gtc = float(gpu_pattern.search(output).group())
        ctf = ctc * 9 / 5 + 32
        gtf = gtc * 9 / 5 + 32

        cpu_temp = f"{ctc:.1f}\u00b0C | {ctf:.1f}\u00b0F"
        gpu_temp = f"{gtc:.1f}\u00b0C | {gtf:.1f}\u00b0F"


        sys.stdout.write(f"\x1b[4mCPU Temp\x1b[0m\n  {cpu_temp}\n\x1b[4mGPU Temp\x1b[0m\n  {gpu_temp}\n")


def hackystats(args):

    details()
    frequency()
    temperature()


def main(argv=None):
    argv = (argv or sys.argv)[1:]
    parser = argparse.ArgumentParser()
    parser.set_defaults(func=hackystats)
    args = parser.parse_args(argv)
    if os.name == 'nt':
        return "This command only works on linux."

    try:
        args.func(args)
    except KeyboardInterrupt:
        sys.stdout.write("Action cancelled by user.\n")


if __name__ == '__main__':
    sys.exit(main())



import os
import sys
from PIL import Image
import argparse


def gifit(args=None, directory=None):

    if directory is None:
        source = args.source
    if not args.output.endswith('.gif'):
        output = f"{args.output.rstrip('.gif')}.gif"
    else:
        output = args.output

    frames = []
    for item in os.scandir(source):
        img = Image.open(item.path)
        frames.append(img.copy())

    frames[0].save(output, save_all=True, append_images=frames[1:], loop=0)
    print(f"Gif {output} created. Enjoy!")
    if sys.platform == 'win32':
        os.system(output)

def main(argv=None):

    argv = (argv or sys.argv)[1:]
    parser = argparse.ArgumentParser()
    parser.add_argument('source', type=str, help='source directory to make the gif with')
    parser.add_argument('output', type=str, help='the desired final output filename')
    parser.set_defaults(func=gifit)
    args = parser.parse_args(argv)
    try:
        args.func(args=args)
    except Exception as e:
        parser.error((str(e)))

if __name__ == '__main__':
    sys.exit(main()) 



from functools import wraps
import sys
import requests
import socket
import time
import shutil
import os
import begin
from glob import glob
from urllib.request import urlopen


def hackywalk(source):
    results = []
    paths = [source]
    while paths:
        for item in os.scandir(paths.pop(0)):
            if item.is_file():
                results.append(item.path)
            elif item.is_dir() and not item.is_symlink():
                paths.append(item.path)
            elif item.is_symlink() and not item.is_dir():
                results.append(item.path)
    return results

def icanhazip():
    return requests.get('https://ipv4.icanhazip.com').text.strip()

def ftime(ns):
    if ns < 1000:
        return f"{ns:.2f} ns"
    elif ns < 1000000:
        return f"{ns/1000:.2f} \u00B5s"
    elif ns < 1000000000:
        return f"{ns/1000000:.2f} ms"
    else:
        return f"{ns/1000000000:.2f} s"

def ftime_ns(ns):
    return ftime(ns)

def elapsed(func):
    @wraps(func)
    def wrapper(*args, **kwargs):
        ts = time.perf_counter_ns()
        result = func(*args, **kwargs)
        te = time.perf_counter_ns() - ts
        sys.stdout.write(f"{func.__qualname__!r} elapsed: {ftime(te)}\n")
        return result
    return wrapper

def bestof(argument=None, freq=7):
    def decorator(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            times = []
            for _ in range(freq):
                ts = time.perf_counter_ns()
                result = func(*args, **kwargs)
                te = time.perf_counter_ns() - ts
                times.append(te)
            avg, best, worst = sum(times)/len(times), min(times), max(times)
            sys.stdout.write(f"{func.__qualname__!r} elapsed (best of {freq}): avg: {ftime(avg)} | best: {ftime(best)} | worst: {ftime(worst)}\n")
            return result
        return wrapper
    if callable(argument):
        return decorator(argument)
    elif isinstance(argument, int):
        freq = argument
    return decorator

def flatten(data):
    return sum(([x] if not isinstance(x, list) else flatten(x) for x in data), [])

def sprint(text):
    return sys.stdout.write(str(text))

def whatsmyip():
    if len(sys.argv) > 1:
        if sys.argv[1].lower() in ['local', '-local', '--local']:
            return socket.gethostbyname(socket.gethostname())
    return requests.get('https://api.ipify.org').text.strip()

# Needs testing

# @begin.start
# def wgetit(url, name=None):
#     if name is None:
#         name = os.path.split(url)[1]
#     try:
#         with open(name, 'wb') as f:
#             f.write(urlopen(url).read())
#             return f"{url} -> {name}"
#     except Exception as e:
#         return str(e)


# @begin.start
# def wcit(*filenames):
    
#     files = [f for g in filenames for f in glob(g)]
#     chars = 0
#     words = 0
#     lines = 0
#     system_dependent_shorthand = '\n' if os.name == 'nt' else ''
#     output = []
#     for file in files:
#         try:
#             with open(file, errors='ignore') as f:
#                 d = f.read()
#             l = len(d.split('\n'))-1
#             w = len(d.split())
#             c = os.path.getsize(file)
#             chars += c
#             words += w
#             lines += l
#             output.append((l, w, c, file))
#         except:
#             pass
#     if len(output) > 2:
#         output.append((lines, words, chars, 'total'))
#     w = max([len(str(i)) for i in (chars,words,lines)])
#     ww = max([len(str(i)) for i in (files)])
#     if w < 5:
#         w = 5
#     for item in output:
#         sys.stdout.write('{:>{width}} {:>{width}} {:>{width}} {:>{wwidth}}\n'.format(*item,width=w,wwidth=ww))

# def spout(text, pos=None):
#     if pos:
#         x,y = pos
#         return sys.stdout.write(f"\x1b[s\x1b[{x};{y}H{text}\x1b[u")
#     return sys.stdout.write(f"{text}")



import os
import sys
import shutil
import argparse
from math import sqrt, ceil, floor
from PIL import Image
from threading import Thread

class Sprite:

    def __init__(self, args):

        self.source = [args.source]
        self.dirs = []
        while self.source:
            path = self.source[0]
            for item in os.scandir(path):
                if item.is_dir():
                    self.source.append(item.path)
                    self.dirs.append(item.path)
            self.source.pop(0)
        if not self.dirs:
            self.dirs = [args.source]
        self.width = args.width
        self.height = args.height
        self.output = args.output
        if os.path.exists(self.output):
            shutil.rmtree(self.output)
        os.mkdir(self.output)

    def spriteit(self):

        p = None
        if len(self.dirs) > 1:
            p = True
        threads = []
        for item in self.dirs:
            t1 = Thread(target=self.single_sheet, args=(item, self.width, self.height, self.output))
            t2 = Thread(target=self.generate_stylesheet, args=(item, self.width, self.height, self.output), kwargs={'project': p})
            threads.extend((t1,t2))
        for thread in threads:
            thread.start()
        for thread in threads:
            thread.join()

    def single_sheet(self, source, width, height, output):
        
        images = [file.path for file in os.scandir(source)]
        if len(images) > ceil(sqrt(len(images))) * floor(sqrt(len(images))):
            rows, cols = ceil(sqrt(len(images))), ceil(sqrt(len(images)))
        else:
            rows, cols = ceil(sqrt(len(images))), floor(sqrt(len(images)))
        size = Image.open(images[0]).size
        canvas = (size[0]*rows,size[1]*cols)
        x = y = 0
        sheet = Image.new('RGBA', canvas)
        for item in images:
            if os.path.isdir(item):
                continue
            sheet.paste(Image.open(item), (x,y))
            x += size[0]
            if x >= canvas[0]:
                x = 0
                y += size[1]
        if width and height:
            sheet = sheet.resize((width*rows, height*cols), Image.LANCZOS)
        # if not os.path.exists(output):
            # os.mkdir(output)
        filename = os.path.join(output, 'flairs-{}.png'.format(os.path.split(source)[1]))
        sheet.save(filename,'PNG')
        print("{} generated.".format(filename.replace('.png', '')))
    
    def generate_stylesheet(self, source, width, height, output, project=None):

        images = [file for file in os.scandir(source)]
        size = Image.open(images[0].path).size
        if width and height:
            size = (width,height)
        x = y = 0
        if len(images) > ceil(sqrt(len(images))) * floor(sqrt(len(images))):
            rows, cols = ceil(sqrt(len(images))), ceil(sqrt(len(images)))
        else:
            rows, cols = ceil(sqrt(len(images))), floor(sqrt(len(images)))
        stylesheet = os.path.join(output,'stylesheet.css')
        lines = []
        folder = ''
        if project:
            folder = os.path.split(os.path.dirname(images[0].path))[1] + '-'
            line = f'\n.flair[class*="{folder[:-1]}-"] {{background-image: url(%%flairs-{folder[:-1]}%%);}}\n\n'
            lines.append(line)
        for item in images:
            if os.path.isdir(item):
                continue
            line = f".flair-{folder}{item.name.replace('.png', '').replace('_4', '')} {{background-position: {'-' if x != 0 else ''}{x}{'px' if x != 0 else ''} {'-' if y != 0 else ''}{y}{'px' if y != 0 else ''};}}\n"
            x += size[0]
            if x >= size[0] * rows:
                x = 0
                y += size[1]
            lines.append(line)
        with open(stylesheet, 'a') as f:
            f.writelines(lines)

def start(args):

    Sprite(args).spriteit()

def main(argv=None):

    argv = (argv or sys.argv)[1:]
    parser = argparse.ArgumentParser()
    parser.add_argument('source')
    parser.add_argument('output', nargs='?', default='sprites')
    parser.add_argument('-x', '--width', dest='width', type=int, default=None)
    parser.add_argument('-y', '--height', dest='height', type=int, default=None)
    parser.add_argument('-xy', '--size', dest='size', type=int, default=None)
    # parser.add_argument('-V', '--version', action='store_true')
    parser.set_defaults(func=start)
    args = parser.parse_args(argv)
    if not args.width and not args.height and args.size:
        args.width = args.height = args.size
    args.func(args)

if __name__ == '__main__':
    sys.exit(main())



import re
from setuptools import find_packages, setup
from codecs import open
from os import path
HERE = path.abspath(path.dirname(__file__))
PACKAGE_NAME = 'hackytools'
with open(path.join(HERE, PACKAGE_NAME, "__init__.py"), encoding="utf-8") as fp:
    VERSION = re.search('__version__ = "([^"]+)"', fp.read()).group(1)

with open('README.md') as f:
    README = f.read()

setup(name=PACKAGE_NAME,
      version=VERSION,
      url="https://github.com/H4CKY54CK/hackytools",
      license="MIT License",
      description="Tools that are hacky. Obviously.",
      long_description=README,
      long_description_content_type="text/markdown",
      author='Hackysack',
      author_email='tk13xr37@gmail.com',
      packages=find_packages(exclude=[]),
      install_requires=['regex'],
      python_requires='>=3.6',
      entry_points={'console_scripts':
        [
            'bork = hackytools.bork:main',
            'whatsmyip = hackytools.utils:whatsmyip',
            'icanhazip = hackytools.utils:icanhazip',
            'spriteit = hackytools.spriteit:main',
        ]
      })
